@@ -34,9 +34,11 @@ extern "C"
 const std::string DrbdMon::OPT_HELP_KEY = "help";
 const std::string DrbdMon::OPT_VERSION_KEY = "version";
 const std::string DrbdMon::OPT_FREQ_LMT_KEY = "freqlmt";
+const std::string DrbdMon::OPT_EVENTS_LOG_KEY = "events-log";
 const ConfigOption DrbdMon::OPT_HELP(true, OPT_HELP_KEY);
 const ConfigOption DrbdMon::OPT_VERSION(true, OPT_VERSION_KEY);
 const ConfigOption DrbdMon::OPT_FREQ_LMT(false, OPT_FREQ_LMT_KEY);
+const ConfigOption DrbdMon::OPT_EVENTS_LOG(false, OPT_EVENTS_LOG_KEY);
 
 const char* DrbdMon::ENV_COLOR_MODE         = "DRBDMON_COLORS";
 const char* DrbdMon::COLOR_MODE_EXTENDED    = "extended";
@@ -71,15 +73,14 @@ DrbdMon::DrbdMon(
     char*                       argv[],
     MonitorEnvironment&         mon_env_ref
 ):
-    sys_api(*(mon_env_ref.sys_api)),
+    mon_env(mon_env_ref),
     arg_count(argc),
     arg_values(argv),
-    fail_data(mon_env_ref.fail_data),
     log(*(mon_env_ref.log)),
     debug_log(*(mon_env_ref.debug_log)),
-    node_name(mon_env_ref.node_name_mgr.get()),
     config(*(mon_env_ref.config))
 {
+    mon_env.fin_action = DrbdMonCore::finish_action::RESTART_IMMED;
     rsc_dir_mgr = std::unique_ptr<ResourceDirectory>(
         new ResourceDirectory(*(mon_env_ref.log), *(mon_env_ref.debug_log))
     );
@@ -92,7 +93,7 @@ DrbdMon::~DrbdMon() noexcept
 
 SystemApi& DrbdMon::get_system_api() const noexcept
 {
-    return sys_api;
+    return *(mon_env.sys_api);
 }
 
 // @throws std::bad_alloc
@@ -109,11 +110,24 @@ void DrbdMon::run()
     {
         try
         {
+            // Interval timer initialization
+            // Must be constructed before configuring the Configurable instances
+            interval_timer_mgr = std::unique_ptr<IntervalTimer>(
+                new IntervalTimer(log, bounds<uint16_t>(0, config.dsp_interval, MAX_INTERVAL))
+            );
+            timer_available = config.dsp_interval != 0;
+            timer_armed = false;
+
+            configurables = std::unique_ptr<Configurable*[]>(new Configurable*[2]);
+            configurables[0] = dynamic_cast<Configurable*> (this);
+            configurables[1] = nullptr;
+            configure_options();
+
             event_props   = std::unique_ptr<PropsMap>(new PropsMap(&comparators::compare_string));
 
             events_source = std::unique_ptr<EventsSourceSpawner>(new EventsSourceSpawner(log));
 
-            events_source->spawn_source();
+            events_source->spawn_source(&(mon_env.events_file_path));
             events_io = std::unique_ptr<EventsIo>(
                 new EventsIo(events_source->get_events_out_fd(), events_source->get_events_err_fd())
             );
@@ -126,21 +140,6 @@ void DrbdMon::run()
                 new SubProcessNotification(dynamic_cast<EventsIoWakeup*> (events_io.get()))
             );
 
-            // Interval timer initialization
-            // Must be constructed before configuring the Configurable instances
-            interval_timer_mgr = std::unique_ptr<IntervalTimer>(
-                new IntervalTimer(log, bounds<uint16_t>(0, config.dsp_interval, MAX_INTERVAL))
-            );
-            timer_available = config.dsp_interval != 0;
-            timer_armed = false;
-
-            configurables = std::unique_ptr<Configurable*[]>(new Configurable*[3]);
-            configurables[0] = dynamic_cast<Configurable*> (this);
-            // configurables[1] = dynamic_cast<Configurable*> (display_impl);
-            configurables[1] = nullptr;
-            configurables[2] = nullptr;
-            configure_options();
-
             // Cleanup any zombies that might not have been collected,
             // because SIGCHLD is blocked during reinitialization
             events_source->cleanup_child_processes();
@@ -158,13 +157,10 @@ void DrbdMon::run()
                 ResourcesMap& prb_rsc_map           = rsc_dir->get_problem_resources_map();
                 display_impl = new DisplayController(
                     *core_instance,
-                    sys_api,
+                    mon_env,
                     *sub_proc_obs,
                     rsc_map,
-                    prb_rsc_map,
-                    log,
-                    config,
-                    node_name
+                    prb_rsc_map
                 );
             }
 
@@ -238,7 +234,7 @@ void DrbdMon::run()
                             case CoreIo::signal_type::SIGNAL_EXIT:
                             {
                                 // Terminate main loop
-                                fin_action = DrbdMonCore::finish_action::TERMINATE;
+                                mon_env.fin_action = DrbdMonCore::finish_action::TERMINATE;
                                 shutdown_flag = true;
                                 break;
                             }
@@ -256,7 +252,7 @@ void DrbdMon::run()
                             }
                             case CoreIo::signal_type::SIGNAL_DEBUG:
                             {
-                                fin_action = DrbdMonCore::finish_action::DEBUG_MODE;
+                                mon_env.fin_action = DrbdMonCore::finish_action::DEBUG_MODE;
                                 shutdown_flag = true;
                                 break;
                             }
@@ -345,8 +341,8 @@ void DrbdMon::run()
                 MessageLog::log_level::ALERT,
                 "The connection to the DRBD events source failed due to an I/O error"
             );
-            fin_action = DrbdMonCore::finish_action::RESTART_DELAYED;
-            fail_data = DrbdMonCore::fail_info::EVENTS_IO;
+            mon_env.fin_action = DrbdMonCore::finish_action::RESTART_DELAYED;
+            mon_env.fail_data = DrbdMonCore::fail_info::EVENTS_IO;
         }
         catch (EventsSourceException& src_exc)
         {
@@ -370,8 +366,8 @@ void DrbdMon::run()
                     *debug_info
                 );
             }
-            fin_action = DrbdMonCore::finish_action::RESTART_DELAYED;
-            fail_data = DrbdMonCore::fail_info::EVENTS_SOURCE;
+            mon_env.fin_action = DrbdMonCore::finish_action::RESTART_DELAYED;
+            mon_env.fail_data = DrbdMonCore::fail_info::EVENTS_SOURCE;
         }
         catch (EventsIoException& io_exc)
         {
@@ -395,8 +391,8 @@ void DrbdMon::run()
                     *debug_info
                 );
             }
-            fin_action = DrbdMonCore::finish_action::RESTART_DELAYED;
-            fail_data = DrbdMonCore::fail_info::EVENTS_IO;
+            mon_env.fin_action = DrbdMonCore::finish_action::RESTART_DELAYED;
+            mon_env.fail_data = DrbdMonCore::fail_info::EVENTS_IO;
         }
         catch (EventException& event_exc)
         {
@@ -436,15 +432,15 @@ void DrbdMon::run()
                 );
             }
 
-            fin_action = DrbdMonCore::finish_action::RESTART_DELAYED;
-            fail_data = DrbdMonCore::fail_info::GENERIC;
+            mon_env.fin_action = DrbdMonCore::finish_action::RESTART_DELAYED;
+            mon_env.fail_data = DrbdMonCore::fail_info::GENERIC;
         }
         catch (ConfigurationException&)
         {
             // A ConfigurationException is thrown to abort and exit
             // while configuring options
             // (--help uses this too)
-            fin_action = DrbdMonCore::finish_action::TERMINATE_NO_CLEAR;
+            mon_env.fin_action = DrbdMonCore::finish_action::TERMINATE_NO_CLEAR;
         }
     }
     catch (std::bad_alloc&)
@@ -458,7 +454,7 @@ void DrbdMon::run()
 
 void DrbdMon::shutdown(const DrbdMonCore::finish_action action) noexcept
 {
-    fin_action = action;
+    mon_env.fin_action = action;
     shutdown_flag = true;
 }
 
@@ -555,7 +551,7 @@ void DrbdMon::process_event_message(
             // Report recovering from errors that triggered reinitialization
             // of the DrbdMon instance
 
-            switch (fail_data)
+            switch (mon_env.fail_data)
             {
                 case DrbdMonCore::fail_info::NONE:
                     // no-op
@@ -596,7 +592,7 @@ void DrbdMon::process_event_message(
             // In case that multiple "exists -" lines are received,
             // which is actually not supposed to happen, avoid spamming
             // the message log
-            fail_data = fail_info::NONE;
+            mon_env.fail_data = fail_info::NONE;
         }
     }
     else
@@ -696,7 +692,7 @@ void DrbdMon::process_event_message(
  */
 DrbdMonCore::finish_action DrbdMon::get_fin_action() const
 {
-    return fin_action;
+    return mon_env.fin_action;
 }
 
 /**
@@ -890,6 +886,7 @@ void DrbdMon::announce_options(Configurator& collector)
     collector.add_config_option(owner, OPT_HELP);
     collector.add_config_option(owner, OPT_VERSION);
     collector.add_config_option(owner, OPT_FREQ_LMT);
+    collector.add_config_option(owner, OPT_EVENTS_LOG);
 }
 
 void DrbdMon::options_help() noexcept
@@ -898,6 +895,7 @@ void DrbdMon::options_help() noexcept
     std::cerr << DrbdMonConsts::PROGRAM_NAME << " configuration options:\n";
     std::cerr << "  --version        Display version information\n";
     std::cerr << "  --help           Display help\n";
+    std::cerr << "  --events-log <file>      Display the DRBD state saved in the specified file\n";
     std::cerr << "  --freqlmt <interval>     Set a frequency limit for display updates\n";
     std::cerr << "    <interval>             Minimum delay between display updates [integer]\n";
     std::cerr << "    Supported unit suffixes: s (seconds), ms (milliseconds)\n";
@@ -911,7 +909,7 @@ void DrbdMon::options_help() noexcept
 }
 
 // @throws std::bad_alloc, ConfigurationException
-void DrbdMon::set_flag(std::string& key)
+void DrbdMon::set_flag(const std::string& key)
 {
     if (key == OPT_HELP.key)
     {
@@ -933,7 +931,7 @@ void DrbdMon::set_flag(std::string& key)
 }
 
 // @throws std::bad_alloc, ConfigurationException
-void DrbdMon::set_option(std::string& key, std::string& value)
+void DrbdMon::set_option(const std::string& key, const std::string& value)
 {
     if (key == OPT_FREQ_LMT.key)
     {
@@ -988,6 +986,11 @@ void DrbdMon::set_option(std::string& key, std::string& value)
             throw ConfigurationException();
         }
     }
+    else
+    if (key == OPT_EVENTS_LOG.key)
+    {
+        mon_env.events_file_path = value;
+    }
 }
 
 uint32_t DrbdMon::get_problem_count() const noexcept
