@@ -26,14 +26,15 @@ class SystemApi
     virtual std::unique_ptr<SubProcess> create_subprocess_handler() = 0;
     virtual std::unique_ptr<TerminalControl> create_terminal_control() = 0;
     virtual std::string get_config_file_path() = 0;
-    virtual bool is_file_accessible(const char* const file_path) = 0;
+    virtual std::string file_name_for_path(const std::string path) const = 0;
+    virtual bool is_file_accessible(const char* const file_path) const = 0;
 };
 
 namespace system_api
 {
     std::unique_ptr<SystemApi> create_system_api();
     bool init_security(MessageLog& log);
-    void init_node_name(std::unique_ptr<std::string>& node_name_mgr);
+    void init_node_name(std::string& node_name);
 }
 
 #endif /* SYSTEMAPI_H */
