@@ -46,7 +46,9 @@ void ComponentsHub::verify() const
         rsc_map == nullptr ||
         prb_rsc_map == nullptr ||
         log == nullptr ||
+        debug_log == nullptr ||
         node_name == nullptr ||
+        events_file == nullptr ||
         ansi_ctl == nullptr ||
         style_coll == nullptr ||
         active_color_table == nullptr ||
