@@ -37,10 +37,12 @@ class ComponentsHub
     ResourcesMap*           rsc_map         {nullptr};
     ResourcesMap*           prb_rsc_map     {nullptr};
     MessageLog*             log             {nullptr};
+    MessageLog*             debug_log       {nullptr};
     GlobalCommands*         global_cmd_exec {nullptr};
     DrbdCommands*           drbd_cmd_exec   {nullptr};
     const Configuration*    config          {nullptr};
     const std::string*      node_name       {nullptr};
+    const std::string*      events_file     {nullptr};
 
     AnsiControl*            ansi_ctl    {nullptr};
     DisplayStyleCollection* style_coll  {nullptr};
@@ -54,6 +56,8 @@ class ComponentsHub
     uint16_t    term_cols       {100};
     uint16_t    term_rows       {30};
 
+    bool        enable_drbd_actions     {true};
+
     ComponentsHub();
     virtual ~ComponentsHub() noexcept;
 
