@@ -25,6 +25,7 @@
 #include <configuration/Configuration.h>
 #include <platform/SystemApi.h>
 #include <DrbdMonCore.h>
+#include <MonitorEnvironment.h>
 #include <MessageLog.h>
 #include <map_types.h>
 #include <VList.h>
@@ -48,13 +49,10 @@ class DisplayController : public GenericDisplay, public DisplaySelector
     // @throws std::bad_alloc, std::logic_error
     DisplayController(
         DrbdMonCore&                core_instance_ref,
-        SystemApi&                  sys_api_ref,
+        MonitorEnvironment&         mon_env_ref,
         SubProcessObserver&         sub_proc_obs_ref,
         ResourcesMap&               rsc_map_ref,
-        ResourcesMap&               prb_rsc_map_ref,
-        MessageLog&                 log_ref,
-        Configuration&              config_ref,
-        const std::string* const    node_name_ptr
+        ResourcesMap&               prb_rsc_map_ref
     );
     virtual ~DisplayController() noexcept;
     DisplayController(const DisplayController& other) = delete;
@@ -86,6 +84,9 @@ class DisplayController : public GenericDisplay, public DisplaySelector
     using DisplayStack = VList<DisplayId::display_page>;
 
     DrbdMonCore&            core_instance;
+    MonitorEnvironment&     mon_env;
+
+    std::string             events_file;
 
     std::unique_ptr<DisplayMap> dsp_map;
 
@@ -121,6 +122,8 @@ class DisplayController : public GenericDisplay, public DisplaySelector
     std::unique_ptr<ModularDisplay>     connection_detail_mgr;
     std::unique_ptr<ModularDisplay>     connection_actions_mgr;
     std::unique_ptr<ModularDisplay>     peer_volume_view_mgr;
+    std::unique_ptr<ModularDisplay>     peer_volume_detail_mgr;
+    std::unique_ptr<ModularDisplay>     peer_volume_actions_mgr;
     std::unique_ptr<ModularDisplay>     active_tasks_mgr;
     std::unique_ptr<ModularDisplay>     pending_tasks_mgr;
     std::unique_ptr<ModularDisplay>     suspended_tasks_mgr;
@@ -129,7 +132,9 @@ class DisplayController : public GenericDisplay, public DisplaySelector
     std::unique_ptr<ModularDisplay>     help_idx_mgr;
     std::unique_ptr<ModularDisplay>     help_view_mgr;
     std::unique_ptr<ModularDisplay>     log_view_mgr;
+    std::unique_ptr<ModularDisplay>     debug_log_view_mgr;
     std::unique_ptr<ModularDisplay>     msg_view_mgr;
+    std::unique_ptr<ModularDisplay>     debug_msg_view_mgr;
     std::unique_ptr<ModularDisplay>     pgm_info_mgr;
     std::unique_ptr<ModularDisplay>     config_mgr;
 
