@@ -10,8 +10,8 @@ class DisplayId
     enum class display_page : uint16_t
     {
         RSC_LIST        = 0,
-        CON_LIST,
         VLM_LIST,
+        CON_LIST,
         PEER_VLM_LIST,
         RSC_DETAIL,
         VLM_DETAIL,
@@ -26,10 +26,13 @@ class DisplayId
         HELP_VIEWER,
         SYNC_LIST,
         LOG_VIEWER,
+        DEBUG_LOG_VIEWER,
         MSG_VIEWER,
+        DEBUG_MSG_VIEWER,
         RSC_ACTIONS,
         VLM_ACTIONS,
         CON_ACTIONS,
+        PEER_VLM_ACTIONS,
         PGM_INFO,
         TASK_DETAIL,
         CONFIGURATION
@@ -51,10 +54,13 @@ class DisplayId
     static const std::string    MDSP_HELP_IDX;
     static const std::string    MDSP_SYNC_LIST;
     static const std::string    MDSP_LOG_VIEW;
+    static const std::string    MDSP_DEBUG_LOG_VIEW;
     static const std::string    MDSP_MSG_VIEW;
+    static const std::string    MDSP_DEBUG_MSG_VIEW;
     static const std::string    MDSP_RSC_ACT;
     static const std::string    MDSP_VLM_ACT;
     static const std::string    MDSP_CON_ACT;
+    static const std::string    MDSP_PEER_VLM_ACT;
     static const std::string    MDSP_PGM_INFO;
     static const std::string    MDSP_TASK_DETAIL;
     static const std::string    MDSP_CONFIGURATION;
