@@ -20,6 +20,8 @@ namespace helptext
         CON_DETAIL,
         CON_ACTIONS,
         PVLM_LIST,
+        PVLM_DETAIL,
+        PVLM_ACTIONS,
         MAIN_MENU,
         MESSAGE_LOG,
         MESSAGE_DETAIL,
@@ -33,7 +35,6 @@ namespace helptext
 
     extern const char* const RSC_LIST_HELP_1;
     extern const char* const RSC_LIST_HELP_2;
-    extern const char* const RSC_LIST_HELP_3;
     extern const char* const RSC_LINE_HELP;
     extern const char* const VLM_LIST_HELP_1;
     extern const char* const VLM_LIST_HELP_2;
@@ -42,6 +43,8 @@ namespace helptext
     extern const char* const PEER_VLM_LIST_HELP_2;
     extern const char* const PEER_VLM_LIST_HELP_3;
     extern const char* const PEER_VLM_LIST_HELP_4;
+    extern const char* const PEER_VLM_DETAIL_HELP_1;
+    extern const char* const PEER_VLM_ACT_HELP_1;
     extern const char* const CON_LIST_HELP_1;
     extern const char* const CON_LIST_HELP_2;
     extern const char* const CON_LIST_HELP_3;
@@ -69,6 +72,7 @@ namespace helptext
     extern const char* const INSERT_NAV_LIST_HELP_1;
     extern const char* const INSERT_RSC_CMD_HELP_1;
     extern const char* const INSERT_VLM_CMD_HELP_1;
+    extern const char* const INSERT_PEER_VLM_CMD_HELP_1;
     extern const char* const INSERT_CON_CMD_HELP_1;
 
     extern void open_help_page(const id_type help_id, const ComponentsHub& dsp_comp_hub);
