@@ -10,6 +10,7 @@
 #include <objects/DrbdResource.h>
 #include <comparators.h>
 #include <bounds.h>
+#include <string_matching.h>
 #include <functional>
 
 const uint8_t   MDspConnections::RSC_HEADER_Y       = 3;
@@ -41,6 +42,8 @@ void MDspConnections::display_activated()
     {
         reset_display();
     }
+    displayed_rsc = dsp_comp_hub.dsp_shared->monitor_rsc;
+    cursor_con = dsp_comp_hub.dsp_shared->monitor_con;
     dsp_comp_hub.dsp_shared->ovrd_connection_selection = false;
 }
 
@@ -53,8 +56,8 @@ void MDspConnections::reset_display()
 {
     MDspStdListBase::reset_display();
     cursor_con.clear();
+    clear_selection();
     set_page_nr(1);
-    displayed_rsc = dsp_comp_hub.dsp_shared->monitor_rsc;
 }
 
 void MDspConnections::display_list()
@@ -442,6 +445,64 @@ void MDspConnections::display_at_page()
     }
 }
 
+// @throws std::bad_alloc, string_matching::PatternLimitException
+bool MDspConnections::change_selection(const std::string& pattern_text, const bool select_flag)
+{
+    DrbdResource* const rsc = dsp_comp_hub.get_monitor_resource();
+    bool matched = false;
+    if (rsc != nullptr)
+    {
+        std::unique_ptr<string_matching::PatternItem> pattern;
+        string_matching::process_pattern(pattern_text, pattern);
+
+        DrbdResource::ConnectionsIterator con_iter = rsc->connections_iterator();
+        if (is_problem_mode(rsc))
+        {
+            while (con_iter.has_next())
+            {
+                DrbdConnection* const con = con_iter.next();
+                if (problem_filter(con))
+                {
+                    const std::string& con_name = con->get_name();
+                    if (string_matching::match_text(con_name, pattern.get()))
+                    {
+                        matched = true;
+                        if (select_flag)
+                        {
+                            dsp_comp_hub.dsp_shared->select_connection(con_name);
+                        }
+                        else
+                        {
+                            dsp_comp_hub.dsp_shared->deselect_connection(con_name);
+                        }
+                    }
+                }
+            }
+        }
+        else
+        {
+            while (con_iter.has_next())
+            {
+                DrbdConnection* const con = con_iter.next();
+                const std::string& con_name = con->get_name();
+                if (string_matching::match_text(con_name, pattern.get()))
+                {
+                    matched = true;
+                    if (select_flag)
+                    {
+                        dsp_comp_hub.dsp_shared->select_connection(con_name);
+                    }
+                    else
+                    {
+                        dsp_comp_hub.dsp_shared->deselect_connection(con_name);
+                    }
+                }
+            }
+        }
+    }
+    return matched;
+}
+
 void MDspConnections::clear_selection()
 {
     dsp_comp_hub.dsp_shared->clear_connections_selection();
@@ -557,20 +618,26 @@ bool MDspConnections::key_pressed(const uint32_t key)
             intercepted = true;
         }
         else
-        if (is_cursor_nav() || dsp_comp_hub.dsp_shared->have_connections_selection())
+        if (is_cursor_nav())
         {
-            if (key == static_cast<uint32_t> ('A') || key == static_cast<uint32_t> ('a'))
-            {
-                dsp_comp_hub.dsp_selector->switch_to_display(DisplayId::display_page::CON_ACTIONS);
-                intercepted = true;
-            }
-            else
             if (key == KeyCodes::ENTER)
             {
                 dsp_comp_hub.dsp_selector->switch_to_display(DisplayId::display_page::CON_DETAIL);
                 intercepted = true;
             }
         }
+
+        if (!intercepted && (is_cursor_nav() || dsp_comp_hub.dsp_shared->have_connections_selection()))
+        {
+            if (key == static_cast<uint32_t> ('A') || key == static_cast<uint32_t> ('a'))
+            {
+                if (dsp_comp_hub.enable_drbd_actions)
+                {
+                    dsp_comp_hub.dsp_selector->switch_to_display(DisplayId::display_page::CON_ACTIONS);
+                    intercepted = true;
+                }
+            }
+        }
     }
     return intercepted;
 }
@@ -603,12 +670,110 @@ bool MDspConnections::execute_command(const std::string& command, StringTokenize
 {
     bool accepted = false;
     if (command == cmd_names::KEY_CMD_CURSOR)
+    {
+        DrbdResource* const rsc = dsp_comp_hub.get_monitor_resource();
+        if (rsc != nullptr)
+        {
+            if (tokenizer.has_next())
+            {
+                const std::string cmd_arg = tokenizer.next();
+                if (!cmd_arg.empty())
+                {
+                    if (string_matching::is_pattern(cmd_arg))
+                    {
+                        dsp_comp_hub.dsp_common->application_working();
+                        try
+                        {
+                            std::unique_ptr<string_matching::PatternItem> pattern;
+                            string_matching::process_pattern(cmd_arg, pattern);
+
+                            DrbdResource::ConnectionsIterator con_iter = rsc->connections_iterator();
+                            if (is_problem_mode(rsc))
+                            {
+                                while (!accepted && con_iter.has_next())
+                                {
+                                    DrbdConnection* const con = con_iter.next();
+                                    if (problem_filter(con))
+                                    {
+                                        const std::string& con_name = con->get_name();
+                                        accepted = string_matching::match_text(con_name, pattern.get());
+
+                                        if (accepted)
+                                        {
+                                            cursor_con = con_name;
+                                        }
+                                    }
+                                }
+                            }
+                            else
+                            {
+                                while (!accepted && con_iter.has_next())
+                                {
+                                    const DrbdConnection* const con = con_iter.next();
+                                    const std::string& con_name = con->get_name();
+                                    accepted = string_matching::match_text(con_name, pattern.get());
+
+                                    if (accepted)
+                                    {
+                                        cursor_con = con_name;
+                                    }
+                                }
+                            }
+                        }
+                        catch (string_matching::PatternLimitException&)
+                        {
+                            std::string error_msg(cmd_names::KEY_CMD_CURSOR);
+                            error_msg += " command rejected: Excessive number of wildcard characters";
+                            dsp_comp_hub.log->add_entry(MessageLog::log_level::ALERT, error_msg);
+                        }
+                    }
+                    else
+                    {
+                        tokenizer.restart();
+                        tokenizer.advance();
+                        accepted = dsp_comp_hub.global_cmd_exec->execute_command(
+                            cmd_names::KEY_CMD_CONNECTION,
+                            tokenizer
+                        );
+                    }
+                }
+            }
+        }
+    }
+    else
+    if (command == cmd_names::KEY_CMD_SELECT || command == cmd_names::KEY_CMD_DESELECT)
     {
         if (tokenizer.has_next())
         {
-            cursor_con = tokenizer.next();
+            std::string cmd_arg = tokenizer.next();
+            if (string_matching::is_pattern(cmd_arg))
+            {
+                dsp_comp_hub.dsp_common->application_working();
+                try
+                {
+                    accepted = change_selection(cmd_arg, command == cmd_names::KEY_CMD_SELECT);
+                }
+                catch (string_matching::PatternLimitException&)
+                {
+                    std::string error_msg(command);
+                    error_msg += " command rejected: Excessive number of wildcard characters";
+                    dsp_comp_hub.log->add_entry(MessageLog::log_level::ALERT, error_msg);
+                }
+            }
+            else
+            {
+                if (command == cmd_names::KEY_CMD_SELECT)
+                {
+                    dsp_comp_hub.dsp_shared->select_connection(cmd_arg);
+                }
+                else
+                {
+                    dsp_comp_hub.dsp_shared->deselect_connection(cmd_arg);
+                }
+                accepted = true;
+            }
         }
-        accepted = true;
+        return accepted;
     }
     else
     if (command == cmd_names::KEY_CMD_SELECT_ALL)
@@ -616,6 +781,7 @@ bool MDspConnections::execute_command(const std::string& command, StringTokenize
         DrbdResource* const rsc = dsp_comp_hub.get_monitor_resource();
         if (rsc != nullptr)
         {
+            dsp_comp_hub.dsp_common->application_working();
             const bool prb_mode = is_problem_mode(rsc);
             DrbdResource::ConnectionsIterator con_iter = rsc->connections_iterator();
             while (con_iter.has_next())
@@ -631,8 +797,9 @@ bool MDspConnections::execute_command(const std::string& command, StringTokenize
         accepted = true;
     }
     else
-    if (command == cmd_names::KEY_CMD_DESELECT)
+    if (command == cmd_names::KEY_CMD_DESELECT_ALL || command == cmd_names::KEY_CMD_CLEAR_SELECTION)
     {
+        dsp_comp_hub.dsp_common->application_working();
         clear_selection();
         accepted = true;
     }
@@ -640,6 +807,11 @@ bool MDspConnections::execute_command(const std::string& command, StringTokenize
     {
         dsp_comp_hub.dsp_selector->refresh_display();
     }
+    else
+    {
+        dsp_comp_hub.dsp_common->application_idle();
+        reposition_text_cursor();
+    }
     return accepted;
 }
 
@@ -801,6 +973,21 @@ void MDspConnections::synchronize_data()
     }
 }
 
+void MDspConnections::notify_data_updated()
+{
+    if (displayed_rsc != dsp_comp_hub.dsp_shared->monitor_rsc)
+    {
+        reset_display();
+    }
+    displayed_rsc = dsp_comp_hub.dsp_shared->monitor_rsc;
+    cursor_con = dsp_comp_hub.dsp_shared->monitor_con;
+    if (!is_cursor_nav())
+    {
+        set_page_nr(1);
+    }
+    dsp_comp_hub.dsp_selector->refresh_display();
+}
+
 uint64_t MDspConnections::get_update_mask() noexcept
 {
     return update_event::UPDATE_FLAG_DRBD;
