@@ -42,6 +42,7 @@ class MDspConnections : public MDspStdListBase
     virtual void display_deactivated() override;
     virtual void reset_display() override;
     virtual void synchronize_data() override;
+    virtual void notify_data_updated() override;
 
     virtual uint64_t get_update_mask() noexcept override;
 
@@ -62,6 +63,8 @@ class MDspConnections : public MDspStdListBase
     void write_no_connections_line(const bool problem_mode_flag);
     void monitor_cursor_common_keys(const uint32_t key);
     bool is_problem_mode(DrbdResource* const rsc);
+    // @throws std::bad_alloc, string_matching::PatternLimitException
+    bool change_selection(const std::string& pattern_text, const bool select_flag);
 
     uint32_t get_lines_per_page();
 };
