@@ -2,6 +2,8 @@
 #define MDSPLOGVIEWER_H
 
 #include <default_types.h>
+#include <MessageLog.h>
+#include <map_types.h>
 #include <terminal/MDspStdListBase.h>
 #include <functional>
 
@@ -13,7 +15,7 @@ class MDspLogViewer : public MDspStdListBase
     static const uint8_t    LOG_HEADER_Y;
     static const uint8_t    LOG_LIST_Y;
 
-    MDspLogViewer(const ComponentsHub& comp_hub);
+    MDspLogViewer(const ComponentsHub& comp_hub, MessageLog& log_ref);
     virtual ~MDspLogViewer() noexcept;
 
     virtual void display_list() override;
@@ -39,11 +41,17 @@ class MDspLogViewer : public MDspStdListBase
     virtual uint64_t get_update_mask() noexcept override;
 
   private:
+    MessageLog& log;
+
     uint32_t get_lines_per_page() noexcept;
     void list_item_clicked(MouseEvent& mouse);
     void display_log_header();
     void write_log_line(MessageLog::Entry* const msg_entry, const bool selecting, uint32_t& current_line);
     void cursor_to_nearest_item();
+    // Returns a reference to the message ID that is shared between displays
+    uint64_t& get_message_id() noexcept;
+    // Returns a reference to the map of selected log entries
+    MessageMap& get_selected_log_entries() noexcept;
 };
 
 #endif /* MDSPLOGVIEWER_H */
