@@ -24,8 +24,6 @@ const uint8_t   MDspPeerVolumes::PEER_VLM_LIST_Y    = 8;
 MDspPeerVolumes::MDspPeerVolumes(const ComponentsHub& comp_hub):
     MDspStdListBase::MDspStdListBase(comp_hub)
 {
-    selected_volumes_mgr = std::unique_ptr<VolumesMap>(new VolumesMap(&comparators::compare<uint16_t>));
-
     problem_filter =
         [](DrbdVolume* vlm) -> bool
         {
@@ -40,7 +38,6 @@ MDspPeerVolumes::MDspPeerVolumes(const ComponentsHub& comp_hub):
 
 MDspPeerVolumes::~MDspPeerVolumes() noexcept
 {
-    clear_selection_impl();
 }
 
 void MDspPeerVolumes::display_list()
@@ -95,7 +92,29 @@ bool MDspPeerVolumes::key_pressed(const uint32_t key)
             dsp_comp_hub.dsp_selector->refresh_display();
             intercepted = true;
         }
+        else
+        if (is_cursor_nav())
+        {
+            if (key == KeyCodes::ENTER)
+            {
+                dsp_comp_hub.dsp_selector->switch_to_display(DisplayId::display_page::PEER_VLM_DETAIL);
+                intercepted = true;
+            }
+        }
+
+        if (!intercepted && (is_cursor_nav() || dsp_comp_hub.dsp_shared->have_peer_volumes_selection()))
+        {
+            if (key == static_cast<uint32_t> ('A') || key == static_cast<uint32_t> ('a'))
+            {
+                if (dsp_comp_hub.enable_drbd_actions)
+                {
+                    dsp_comp_hub.dsp_selector->switch_to_display(DisplayId::display_page::PEER_VLM_ACTIONS);
+                    intercepted = true;
+                }
+            }
+        }
     }
+
     return intercepted;
 }
 
@@ -104,12 +123,18 @@ bool MDspPeerVolumes::mouse_action(MouseEvent& mouse)
     bool intercepted = MDspStdListBase::mouse_action(mouse);
     if (!intercepted)
     {
-        if (mouse.coord_row >= PEER_VLM_LIST_Y)
+        if ((mouse.button == MouseEvent::button_id::BUTTON_01 || mouse.button == MouseEvent::button_id::BUTTON_03) &&
+            mouse.event == MouseEvent::event_id::MOUSE_RELEASE &&
+            mouse.coord_row >= PEER_VLM_LIST_Y)
         {
             const uint32_t lines_per_page = get_lines_per_page();
             if (mouse.coord_row < PEER_VLM_LIST_Y + lines_per_page)
             {
                 list_item_clicked(mouse);
+                if (mouse.button == MouseEvent::button_id::BUTTON_03 && is_cursor_nav())
+                {
+                    dsp_comp_hub.dsp_selector->switch_to_display(DisplayId::display_page::PEER_VLM_DETAIL);
+                }
                 intercepted = true;
             }
         }
@@ -136,46 +161,104 @@ bool MDspPeerVolumes::execute_command(const std::string& command, StringTokenize
             }
         }
     }
+    else
+    if (command == cmd_names::KEY_CMD_SELECT || command == cmd_names::KEY_CMD_DESELECT)
+    {
+        if (tokenizer.has_next())
+        {
+            const std::string obj_id = tokenizer.next();
+            try
+            {
+                const uint16_t vlm_id = dsaext::parse_unsigned_int16(obj_id);
+                if (command == cmd_names::KEY_CMD_SELECT)
+                {
+                    select_volume(vlm_id);
+                }
+                else
+                {
+                    deselect_volume(vlm_id);
+                }
+                accepted = true;
+            }
+            catch (dsaext::NumberFormatException&)
+            {
+                // ignored, command rejected
+            }
+        }
+        return accepted;
+    }
+    else
+    if (command == cmd_names::KEY_CMD_SELECT_ALL)
+    {
+        DrbdResource* const rsc = dsp_comp_hub.get_monitor_resource();
+        DrbdConnection* const con = dsp_comp_hub.get_monitor_connection();
+        if (rsc != nullptr && con != nullptr)
+        {
+            dsp_comp_hub.dsp_common->application_working();
+            DrbdConnection::VolumesIterator vlm_iter(*con);
+            if (is_problem_mode(rsc, con))
+            {
+                while (vlm_iter.has_next())
+                {
+                    DrbdVolume* const peer_vlm = vlm_iter.next();
+                    if (problem_filter(peer_vlm))
+                    {
+                        const uint16_t vlm_nr = peer_vlm->get_volume_nr();
+                        select_volume(vlm_nr);
+                    }
+                }
+            }
+            else
+            {
+                while (vlm_iter.has_next())
+                {
+                    DrbdVolume* const peer_vlm = vlm_iter.next();
+                    const uint16_t vlm_nr = peer_vlm->get_volume_nr();
+                    select_volume(vlm_nr);
+                }
+            }
+        }
+        accepted = true;
+    }
+    else
+    if (command == cmd_names::KEY_CMD_DESELECT_ALL || command == cmd_names::KEY_CMD_CLEAR_SELECTION)
+    {
+        dsp_comp_hub.dsp_common->application_working();
+        clear_selection();
+        accepted = true;
+    }
     if (accepted)
     {
         dsp_comp_hub.dsp_selector->refresh_display();
     }
+    else
+    {
+        dsp_comp_hub.dsp_common->application_idle();
+        reposition_text_cursor();
+    }
     return accepted;
 }
 
 void MDspPeerVolumes::clear_selection()
 {
-    clear_selection_impl();
+    dsp_comp_hub.dsp_shared->clear_peer_volumes_selection();
 }
 
 bool MDspPeerVolumes::is_selecting()
 {
-    return selecting;
+    return dsp_comp_hub.dsp_shared->have_peer_volumes_selection();
 }
 
 void MDspPeerVolumes::toggle_select_cursor_item()
 {
-    if (!dsp_comp_hub.dsp_shared->monitor_rsc.empty() && !dsp_comp_hub.dsp_shared->monitor_con.empty() &&
-        cursor_vlm != DisplayConsts::VLM_NONE)
+    if (cursor_vlm != DisplayConsts::VLM_NONE)
     {
+        DrbdResource* const rsc = dsp_comp_hub.get_monitor_resource();
         DrbdConnection* const con = dsp_comp_hub.get_monitor_connection();
-        if (con != nullptr)
+        if (rsc != nullptr && con != nullptr)
         {
-            DrbdVolume* const vlm = con->get_volume(cursor_vlm);
-            if (vlm != nullptr)
-            {
-                VolumesMap* const selected_volumes = selected_volumes_mgr.get();
-                VolumesMap::Node* const existing_entry = selected_volumes->get_node(&cursor_vlm);
-                if (existing_entry == nullptr)
-                {
-                    select_volume(cursor_vlm);
-                }
-                else
-                {
-                    deselect_volume(cursor_vlm);
-                }
-                dsp_comp_hub.dsp_selector->refresh_display();
-            }
+            dsp_comp_hub.dsp_shared->toggle_peer_volume_selection(cursor_vlm);
+            dsp_comp_hub.dsp_selector->refresh_display();
         }
     }
 }
@@ -285,39 +368,25 @@ void MDspPeerVolumes::clear_cursor()
 
 void MDspPeerVolumes::select_volume(const uint16_t vlm_nr)
 {
-    VolumesMap* const selected_volumes = selected_volumes_mgr.get();
-    const VolumesMap::Node* const existing_entry = selected_volumes->get_node(&vlm_nr);
-    if (existing_entry == nullptr)
-    {
-        std::unique_ptr<uint16_t> key_mgr(new uint16_t);
-        uint16_t* const key = key_mgr.get();
-        *key = vlm_nr;
-
-        selected_volumes->insert(key, nullptr);
-        key_mgr.release();
-        selecting = true;
-    }
+    dsp_comp_hub.dsp_shared->select_peer_volume(vlm_nr);
 }
 
 void MDspPeerVolumes::deselect_volume(const uint16_t vlm_nr)
 {
-    VolumesMap* const selected_volumes = selected_volumes_mgr.get();
-    VolumesMap::Node* const existing_entry = selected_volumes->get_node(&vlm_nr);
-    if (existing_entry != nullptr)
-    {
-        delete existing_entry->get_key();
-        selected_volumes->remove_node(existing_entry);
-        selecting = selected_volumes->get_size() >= 1;
-    }
+    dsp_comp_hub.dsp_shared->deselect_peer_volume(vlm_nr);
 }
 
 void MDspPeerVolumes::display_activated()
 {
     MDspStdListBase::display_activated();
-    if (displayed_rsc != dsp_comp_hub.dsp_shared->monitor_rsc || displayed_con != dsp_comp_hub.dsp_shared->monitor_con)
+    if (displayed_rsc != dsp_comp_hub.dsp_shared->monitor_rsc)
     {
         reset_display();
     }
+    displayed_rsc = dsp_comp_hub.dsp_shared->monitor_rsc;
+    displayed_con = dsp_comp_hub.dsp_shared->monitor_con;
+    cursor_vlm = dsp_comp_hub.dsp_shared->monitor_peer_vlm;
+    dsp_comp_hub.dsp_shared->ovrd_peer_volume_selection = false;
 }
 
 void MDspPeerVolumes::display_deactivated()
@@ -329,27 +398,28 @@ void MDspPeerVolumes::reset_display()
 {
     MDspStdListBase::reset_display();
     cursor_vlm = DisplayConsts::VLM_NONE;
-    clear_selection_impl();
+    clear_selection();
     set_page_nr(1);
-    displayed_rsc = dsp_comp_hub.dsp_shared->monitor_rsc;
-    displayed_con = dsp_comp_hub.dsp_shared->monitor_con;
 }
 
 void MDspPeerVolumes::synchronize_data()
 {
-    dsp_comp_hub.dsp_shared->monitor_peer_vlm = cursor_vlm;
+    dsp_comp_hub.dsp_shared->update_monitor_peer_vlm(cursor_vlm);
 }
 
-void MDspPeerVolumes::clear_selection_impl() noexcept
+void MDspPeerVolumes::notify_data_updated()
 {
-    VolumesMap::KeysIterator iter(*(selected_volumes_mgr));
-    while (iter.has_next())
+    if (displayed_rsc != dsp_comp_hub.dsp_shared->monitor_rsc)
     {
-        const uint16_t* const key = iter.next();
-        delete key;
+        reset_display();
     }
-    selected_volumes_mgr->clear();
-    selecting = false;
+    displayed_con = dsp_comp_hub.dsp_shared->monitor_con;
+    cursor_vlm = dsp_comp_hub.dsp_shared->monitor_peer_vlm;
+    if (!is_cursor_nav())
+    {
+        set_page_nr(1);
+    }
+    dsp_comp_hub.dsp_selector->refresh_display();
 }
 
 void MDspPeerVolumes::display_volume_header()
@@ -384,6 +454,7 @@ void MDspPeerVolumes::display_at_cursor()
     DrbdConnection* const con = dsp_comp_hub.get_monitor_connection();
     if (rsc != nullptr && con != nullptr)
     {
+        const bool selecting = dsp_comp_hub.dsp_shared->have_peer_volumes_selection();
         const uint16_t vlm_count = con->get_volume_count();
         const bool problem_mode_flag = is_problem_mode(rsc, con);
         dsp_comp_hub.dsp_common->display_problem_mode_label(problem_mode_flag);
@@ -422,7 +493,7 @@ void MDspPeerVolumes::display_at_cursor()
                     if (problem_filter(vlm))
                     {
                         dsp_comp_hub.dsp_io->cursor_xy(1, PEER_VLM_LIST_Y + line_nr);
-                        write_volume_line(vlm, current_line);
+                        write_volume_line(vlm, current_line, selecting);
                         ++line_nr;
                     }
                 }
@@ -455,7 +526,7 @@ void MDspPeerVolumes::display_at_cursor()
                 {
                     DrbdVolume* const vlm = dsp_vlm_iter.next();
                     dsp_comp_hub.dsp_io->cursor_xy(1, PEER_VLM_LIST_Y + line_nr);
-                    write_volume_line(vlm, current_line);
+                    write_volume_line(vlm, current_line, selecting);
                     ++line_nr;
                 }
             }
@@ -476,6 +547,7 @@ void MDspPeerVolumes::display_at_page()
     DrbdConnection* const con = dsp_comp_hub.get_monitor_connection();
     if (dsp_rsc != nullptr && con != nullptr)
     {
+        const bool selecting = dsp_comp_hub.dsp_shared->have_peer_volumes_selection();
         const uint32_t lines_per_page = get_lines_per_page();
         const bool problem_mode_flag = is_problem_mode(dsp_rsc, con);
         dsp_comp_hub.dsp_common->display_problem_mode_label(problem_mode_flag);
@@ -499,7 +571,7 @@ void MDspPeerVolumes::display_at_page()
                     if (problem_filter(dsp_vlm))
                     {
                         dsp_io->cursor_xy(1, PEER_VLM_LIST_Y + line_nr);
-                        write_volume_line(dsp_vlm, current_line);
+                        write_volume_line(dsp_vlm, current_line, selecting);
                         ++line_nr;
                     }
                 }
@@ -523,7 +595,7 @@ void MDspPeerVolumes::display_at_page()
             {
                 DrbdVolume* const vlm = vlm_iter.next();
                 dsp_io->cursor_xy(1, PEER_VLM_LIST_Y + line_nr);
-                write_volume_line(vlm, current_line);
+                write_volume_line(vlm, current_line, selecting);
                 ++line_nr;
             }
         }
@@ -596,7 +668,7 @@ void MDspPeerVolumes::list_item_clicked(MouseEvent& mouse)
     }
 }
 
-void MDspPeerVolumes::write_volume_line(DrbdVolume* const vlm, uint32_t& current_line)
+void MDspPeerVolumes::write_volume_line(DrbdVolume* const vlm, uint32_t& current_line, const bool selecting)
 {
     DisplayIo* const dsp_io = dsp_comp_hub.dsp_io;
     dsp_io->cursor_xy(1, current_line);
@@ -612,7 +684,7 @@ void MDspPeerVolumes::write_volume_line(DrbdVolume* const vlm, uint32_t& current
     bool is_selected = false;
     if (selecting)
     {
-        is_selected = selected_volumes_mgr->get_node(&vlm_nr) != nullptr;
+        is_selected = dsp_comp_hub.dsp_shared->is_peer_volume_selected(vlm_nr);
     }
 
     const std::string& rst_bg = is_under_cursor ? dsp_comp_hub.active_color_table->bg_cursor :
