@@ -47,6 +47,7 @@ class MDspPeerVolumes : public MDspStdListBase
     virtual void display_deactivated() override;
     virtual void reset_display() override;
     virtual void synchronize_data() override;
+    virtual void notify_data_updated() override;
 
     virtual uint64_t get_update_mask() noexcept override;
 
@@ -55,19 +56,15 @@ class MDspPeerVolumes : public MDspStdListBase
     std::string displayed_con;
 
     uint16_t    cursor_vlm      {DisplayConsts::VLM_NONE};
-    bool        selecting       {false};
 
     std::function<bool(DrbdVolume*)>                problem_filter;
     std::function<const uint16_t&(DrbdVolume*)>     vlm_key_func;
 
-    std::unique_ptr<VolumesMap> selected_volumes_mgr;
-
-    void clear_selection_impl() noexcept;
     void display_volume_header();
     void display_at_cursor();
     void display_at_page();
     void list_item_clicked(MouseEvent& mouse);
-    void write_volume_line(DrbdVolume* const vlm, uint32_t& current_line);
+    void write_volume_line(DrbdVolume* const vlm, uint32_t& current_line, const bool selecting);
     bool is_problem_mode(DrbdResource* const rsc, DrbdConnection* const con);
 
     uint32_t get_lines_per_page();
