@@ -216,6 +216,21 @@ MDspResourceActions::~MDspResourceActions() noexcept
 }
 
 void MDspResourceActions::display_content()
+{
+    if (dsp_comp_hub.enable_drbd_actions)
+    {
+        show_actions();
+    }
+    else
+    {
+        dsp_comp_hub.dsp_common->display_page_id(DisplayId::MDSP_CON_ACT);
+
+        dsp_comp_hub.dsp_io->cursor_xy(1, DisplayConsts::PAGE_NAV_Y + 3);
+        dsp_comp_hub.dsp_io->write_text("This page is currently disabled");
+    }
+}
+
+void MDspResourceActions::show_actions()
 {
     dsp_comp_hub.dsp_common->display_page_id(DisplayId::MDSP_RSC_ACT);
 
@@ -225,7 +240,14 @@ void MDspResourceActions::display_content()
     {
         ResourcesMap& selection_map = dsp_comp_hub.dsp_shared->get_selected_resources_map();
         const size_t count = selection_map.get_size();
-        dsp_comp_hub.dsp_io->write_fmt("%lu selected resources", static_cast<unsigned long> (count));
+        if (count > 1)
+        {
+            dsp_comp_hub.dsp_io->write_fmt("%lu selected resources", static_cast<unsigned long> (count));
+        }
+        else
+        {
+            dsp_comp_hub.dsp_io->write_fmt("%lu selected resource", static_cast<unsigned long> (count));
+        }
     }
     else
     if (!dsp_comp_hub.dsp_shared->monitor_rsc.empty())
@@ -523,8 +545,9 @@ void MDspResourceActions::action_invalidate(const std::string& rsc_name)
 
     std::string text;
     text.reserve(DisplayConsts::ACTION_DESC_PREALLOC);
-    text.append("Invalidate data & resync resource ");
+    text.append("Invalidate local data, resource ");
     text.append(rsc_name);
+    text.append(", all volumes");
 
     command->set_description(text);
 
