@@ -7,9 +7,10 @@
 #include <terminal/navigation.h>
 #include <terminal/HelpText.h>
 #include <terminal/GlobalCommandConsts.h>
-#include <comparators.h>
 #include <objects/DrbdVolume.h>
 #include <objects/DrbdConnection.h>
+#include <comparators.h>
+#include <string_matching.h>
 #include <bounds.h>
 
 const uint8_t  MDspResources::RSC_HEADER_Y      = 3;
@@ -32,6 +33,7 @@ MDspResources::~MDspResources() noexcept
 void MDspResources::display_activated()
 {
     MDspStdListBase::display_activated();
+    cursor_rsc = dsp_comp_hub.dsp_shared->monitor_rsc;
     dsp_comp_hub.dsp_shared->ovrd_resource_selection = false;
 }
 
@@ -43,6 +45,8 @@ void MDspResources::display_deactivated()
 void MDspResources::reset_display()
 {
     MDspStdListBase::reset_display();
+    cursor_rsc.clear();
+    set_page_nr(1);
 }
 
 void MDspResources::display_list()
@@ -548,8 +552,11 @@ bool MDspResources::key_pressed(const uint32_t key)
         {
             if (key == static_cast<uint32_t> ('a') || key == static_cast<uint32_t> ('A'))
             {
-                dsp_comp_hub.dsp_selector->switch_to_display(DisplayId::display_page::RSC_ACTIONS);
-                intercepted = true;
+                if (dsp_comp_hub.enable_drbd_actions)
+                {
+                    dsp_comp_hub.dsp_selector->switch_to_display(DisplayId::display_page::RSC_ACTIONS);
+                    intercepted = true;
+                }
             }
         }
     }
@@ -587,13 +594,85 @@ bool MDspResources::execute_command(const std::string& command, StringTokenizer&
     {
         if (tokenizer.has_next())
         {
-            cursor_rsc = tokenizer.next();
+            const std::string cmd_arg = tokenizer.next();
+            if (!cmd_arg.empty())
+            {
+                if (string_matching::is_pattern(cmd_arg))
+                {
+                    dsp_comp_hub.dsp_common->application_working();
+                    try
+                    {
+                        std::unique_ptr<string_matching::PatternItem> pattern;
+                        string_matching::process_pattern(cmd_arg, pattern);
+
+                        ResourcesMap& selected_map = select_resources_map();
+                        ResourcesMap::KeysIterator rsc_iter(selected_map);
+                        while (!accepted && rsc_iter.has_next())
+                        {
+                            const std::string* const rsc_name_ptr = rsc_iter.next();
+                            const std::string& rsc_name = *rsc_name_ptr;
+                            accepted = string_matching::match_text(rsc_name, pattern.get());
+                            if (accepted)
+                            {
+                                cursor_rsc = rsc_name;
+                            }
+                        }
+                    }
+                    catch (string_matching::PatternLimitException&)
+                    {
+                        std::string error_msg(cmd_names::KEY_CMD_CURSOR);
+                        error_msg += " command rejected: Excessive number of wildcard characters";
+                        dsp_comp_hub.log->add_entry(MessageLog::log_level::ALERT, error_msg);
+                    }
+                }
+                else
+                {
+                    tokenizer.restart();
+                    tokenizer.advance();
+                    accepted = dsp_comp_hub.global_cmd_exec->execute_command(cmd_names::KEY_CMD_RESOURCE, tokenizer);
+                }
+            }
         }
-        accepted = true;
+    }
+    else
+    if (command == cmd_names::KEY_CMD_SELECT || command == cmd_names::KEY_CMD_DESELECT)
+    {
+        if (tokenizer.has_next())
+        {
+            std::string cmd_arg = tokenizer.next();
+            if (string_matching::is_pattern(cmd_arg))
+            {
+                dsp_comp_hub.dsp_common->application_working();
+                try
+                {
+                    accepted = change_selection(cmd_arg, command == cmd_names::KEY_CMD_SELECT);
+                }
+                catch (string_matching::PatternLimitException&)
+                {
+                    std::string error_msg(command);
+                    error_msg += " command rejected: Excessive number of wildcard characters";
+                    dsp_comp_hub.log->add_entry(MessageLog::log_level::ALERT, error_msg);
+                }
+            }
+            else
+            {
+                if (command == cmd_names::KEY_CMD_SELECT)
+                {
+                    dsp_comp_hub.dsp_shared->select_resource(cmd_arg);
+                }
+                else
+                {
+                    dsp_comp_hub.dsp_shared->deselect_resource(cmd_arg);
+                }
+                accepted = true;
+            }
+        }
+        return accepted;
     }
     else
     if (command == cmd_names::KEY_CMD_SELECT_ALL)
     {
+        dsp_comp_hub.dsp_common->application_working();
         ResourcesMap& selected_map = select_resources_map();
         ResourcesMap::KeysIterator rsc_iter(selected_map);
         while (rsc_iter.has_next())
@@ -604,16 +683,21 @@ bool MDspResources::execute_command(const std::string& command, StringTokenizer&
         accepted = true;
     }
     else
-    if (command == cmd_names::KEY_CMD_DESELECT)
+    if (command == cmd_names::KEY_CMD_DESELECT_ALL || command == cmd_names::KEY_CMD_CLEAR_SELECTION)
     {
+        dsp_comp_hub.dsp_common->application_working();
         clear_selection();
-
         accepted = true;
     }
     if (accepted)
     {
         dsp_comp_hub.dsp_selector->refresh_display();
     }
+    else
+    {
+        dsp_comp_hub.dsp_common->application_idle();
+        reposition_text_cursor();
+    }
     return accepted;
 }
 
@@ -683,6 +767,35 @@ void MDspResources::toggle_select_cursor_item()
     }
 }
 
+// @throws std::bad_alloc, string_matching::PatternLimitException
+bool MDspResources::change_selection(const std::string& pattern_text, const bool select_flag)
+{
+    ResourcesMap& selected_map = select_resources_map();
+    std::unique_ptr<string_matching::PatternItem> pattern;
+    string_matching::process_pattern(pattern_text, pattern);
+
+    bool matched = false;
+    ResourcesMap::KeysIterator rsc_iter(selected_map);
+    while (rsc_iter.has_next())
+    {
+        const std::string* const rsc_name_ptr = rsc_iter.next();
+        const std::string& rsc_name = *rsc_name_ptr;
+        if (string_matching::match_text(rsc_name, pattern.get()))
+        {
+            matched = true;
+            if (select_flag)
+            {
+                dsp_comp_hub.dsp_shared->select_resource(rsc_name);
+            }
+            else
+            {
+                dsp_comp_hub.dsp_shared->deselect_resource(rsc_name);
+            }
+        }
+    }
+    return matched;
+}
+
 // Public entry point to private/non-virtual clear_selection_impl, which is also used by the destructor
 void MDspResources::clear_selection()
 {
@@ -701,6 +814,16 @@ void MDspResources::synchronize_data()
     }
 }
 
+void MDspResources::notify_data_updated()
+{
+    cursor_rsc = dsp_comp_hub.dsp_shared->monitor_rsc;
+    if (!is_cursor_nav())
+    {
+        set_page_nr(1);
+    }
+    dsp_comp_hub.dsp_selector->refresh_display();
+}
+
 uint64_t MDspResources::get_update_mask() noexcept
 {
     return update_event::UPDATE_FLAG_DRBD;
