@@ -40,6 +40,7 @@ class MDspResources : public MDspStdListBase
     virtual void display_deactivated() override;
     virtual void reset_display() override;
     virtual void synchronize_data() override;
+    virtual void notify_data_updated() override;
 
     virtual uint64_t get_update_mask() noexcept override;
 
@@ -56,6 +57,8 @@ class MDspResources : public MDspStdListBase
     void write_resource_line(DrbdResource* const rsc, uint32_t& current_line, const bool selecting);
     void write_no_resources_line(const bool problem_mode_flag);
     bool is_problem_mode(DrbdResource* const rsc);
+    // @throws std::bad_alloc, string_matching::PatternLimitException
+    bool change_selection(const std::string& pattern_text, const bool select_flag);
 
     uint32_t get_lines_per_page();
     DrbdResource* find_resource_near_cursor(ResourcesMap& selected_map);
