@@ -43,6 +43,8 @@ void MDspVolumes::display_activated()
     {
         reset_display();
     }
+    displayed_rsc = dsp_comp_hub.dsp_shared->monitor_rsc;
+    cursor_vlm = dsp_comp_hub.dsp_shared->monitor_vlm;
     dsp_comp_hub.dsp_shared->ovrd_volume_selection = false;
 }
 
@@ -57,7 +59,6 @@ void MDspVolumes::reset_display()
     cursor_vlm = DisplayConsts::VLM_NONE;
     clear_selection();
     set_page_nr(1);
-    displayed_rsc = dsp_comp_hub.dsp_shared->monitor_rsc;
 }
 
 void MDspVolumes::display_list()
@@ -307,20 +308,26 @@ bool MDspVolumes::key_pressed(const uint32_t key)
             intercepted = true;
         }
         else
-        if (is_cursor_nav() || dsp_comp_hub.dsp_shared->have_volumes_selection())
+        if (is_cursor_nav())
         {
-            if (key == static_cast<uint32_t> ('A') || key == static_cast<uint32_t> ('a'))
-            {
-                dsp_comp_hub.dsp_selector->switch_to_display(DisplayId::display_page::VLM_ACTIONS);
-                intercepted = true;
-            }
-            else
             if (key == KeyCodes::ENTER)
             {
                 dsp_comp_hub.dsp_selector->switch_to_display(DisplayId::display_page::VLM_DETAIL);
                 intercepted = true;
             }
         }
+
+        if (!intercepted && (is_cursor_nav() || dsp_comp_hub.dsp_shared->have_volumes_selection()))
+        {
+            if (key == static_cast<uint32_t> ('A') || key == static_cast<uint32_t> ('a'))
+            {
+                if (dsp_comp_hub.enable_drbd_actions)
+                {
+                    dsp_comp_hub.dsp_selector->switch_to_display(DisplayId::display_page::VLM_ACTIONS);
+                    intercepted = true;
+                }
+            }
+        }
     }
     return intercepted;
 }
@@ -365,15 +372,43 @@ bool MDspVolumes::execute_command(const std::string& command, StringTokenizer& t
             }
             catch (dsaext::NumberFormatException&)
             {
+                // ignored, command rejected
             }
         }
     }
     else
+    if (command == cmd_names::KEY_CMD_SELECT || command == cmd_names::KEY_CMD_DESELECT)
+    {
+        if (tokenizer.has_next())
+        {
+            const std::string obj_id = tokenizer.next();
+            try
+            {
+                const uint16_t vlm_id = dsaext::parse_unsigned_int16(obj_id);
+                if (command == cmd_names::KEY_CMD_SELECT)
+                {
+                    dsp_comp_hub.dsp_shared->select_volume(vlm_id);
+                }
+                else
+                {
+                    dsp_comp_hub.dsp_shared->deselect_volume(vlm_id);
+                }
+                accepted = true;
+            }
+            catch (dsaext::NumberFormatException&)
+            {
+                // ignored, command rejected
+            }
+        }
+        return accepted;
+    }
+    else
     if (command == cmd_names::KEY_CMD_SELECT_ALL)
     {
         DrbdResource* const rsc = dsp_comp_hub.get_monitor_resource();
         if (rsc != nullptr)
         {
+            dsp_comp_hub.dsp_common->application_working();
             const bool prb_mode = is_problem_mode(rsc);
             DrbdResource::VolumesIterator vlm_iter = rsc->volumes_iterator();
             while (vlm_iter.has_next())
@@ -389,8 +424,9 @@ bool MDspVolumes::execute_command(const std::string& command, StringTokenizer& t
         accepted = true;
     }
     else
-    if (command == cmd_names::KEY_CMD_DESELECT)
+    if (command == cmd_names::KEY_CMD_DESELECT_ALL || command == cmd_names::KEY_CMD_CLEAR_SELECTION)
     {
+        dsp_comp_hub.dsp_common->application_working();
         clear_selection();
         accepted = true;
     }
@@ -398,6 +434,11 @@ bool MDspVolumes::execute_command(const std::string& command, StringTokenizer& t
     {
         dsp_comp_hub.dsp_selector->refresh_display();
     }
+    else
+    {
+        dsp_comp_hub.dsp_common->application_idle();
+        reposition_text_cursor();
+    }
     return accepted;
 }
 
@@ -784,7 +825,22 @@ bool MDspVolumes::is_problem_mode(DrbdResource* const rsc)
 
 void MDspVolumes::synchronize_data()
 {
-    dsp_comp_hub.dsp_shared->monitor_vlm = cursor_vlm;
+    dsp_comp_hub.dsp_shared->update_monitor_vlm(cursor_vlm);
+}
+
+void MDspVolumes::notify_data_updated()
+{
+    if (displayed_rsc != dsp_comp_hub.dsp_shared->monitor_rsc)
+    {
+        reset_display();
+    }
+    displayed_rsc = dsp_comp_hub.dsp_shared->monitor_rsc;
+    cursor_vlm = dsp_comp_hub.dsp_shared->monitor_vlm;
+    if (!is_cursor_nav())
+    {
+        set_page_nr(1);
+    }
+    dsp_comp_hub.dsp_selector->refresh_display();
 }
 
 uint64_t MDspVolumes::get_update_mask() noexcept
