@@ -1,5 +1,5 @@
 /* These are common functions that are used across _all_ userspace,
- * ie. even across 9, 84, and 83.
+ * ie. even across 9, and 84.
  *
  * Deduplicated here for easier maintenance. */
 
@@ -184,14 +184,18 @@ int sget_token(char *s, int size, const char** text)
 	*sp = 0; /* terminate even if nothing is found */
 	--size;  /* account for the terminating NUL */
 	do { // eat white spaces in front.
-		c = *(*text)++;
-		if( c == 0) return EOF;
+		c = **text;
+		if (!c)
+			return EOF;
+		(*text)++;
 	} while (!isgraph(c));
 
 	do { // read the first word into s
 		*sp++ = c;
-		c = *(*text)++;
-		if ( c == 0) break;
+		c = **text;
+		if (!c)
+			break;
+		(*text)++;
 	} while (isgraph(c) && --size);
 
 	*sp=0;
@@ -542,13 +546,13 @@ m_strtoll(const char *s, const char def_unit)
 		fprintf(stderr, "%s is not a valid number\n", s);
 		exit(20);
 	case MSE_INVALID_UNIT:
-		fprintf(stderr, "%s is not a valid number\n", s);
+		fprintf(stderr, "%s is not a valid unit\n", s);
 		exit(20);
 	case MSE_OUT_OF_RANGE:
 		fprintf(stderr, "%s: out of range\n", s);
 		exit(20);
 	default:
-		fprintf(stderr, "m_stroll() is confused\n");
+		fprintf(stderr, "m_strtoll() is confused\n");
 		exit(20);
 	}
 }
