@@ -193,7 +193,6 @@ extern void schedule_deferred_cmd( int (*function)(struct cfg_ctx *),
 extern int version_code_kernel(void);
 extern int version_code_userland(void);
 extern void warn_on_version_mismatch(void);
-extern void maybe_exec_drbdadm_83(char **argv);
 extern void uc_node(enum usage_count_type type);
 extern void convert_discard_opt(struct d_resource* res);
 extern void convert_after_option(struct d_resource* res);
@@ -242,7 +241,6 @@ extern int dry_run;
 extern int verbose;
 extern char* drbdsetup;
 extern char* drbd_proxy_ctl;
-extern char* drbdadm_83;
 extern char ss_buffer[1024];
 extern struct utsname nodeinfo;
 extern char* connect_to_host;
