@@ -6,7 +6,10 @@
 #include <sys/socket.h>
 #include <linux/netlink.h>
 #include <linux/genetlink.h>
+
+#ifdef KEYUTILS
 #include <keyutils.h>
+#endif
 
 #include "libgenl.h"
 #include "linux/drbd.h"
@@ -694,6 +697,7 @@ struct field_class fc_string = {
 
 /* ---------------------------------------------------------------------------------------------- */
 
+#ifdef KEYUTILS
 static key_serial_t string_to_key_serial(const char *value, const char *key_type)
 {
 	if (!value)
@@ -767,6 +771,52 @@ static enum check_codes key_serial_check(const struct field_def *field, const ch
 	return CC_OK;
 }
 
+#else
+
+static bool key_serial_is_default(const struct field_def *field, const char *value)
+{
+	return true;
+}
+
+static bool key_serial_is_equal(const struct field_def *field, const char *a, const char *b)
+{
+	return true;
+}
+
+static const char *get_key_serial(struct context_def *ctx, const struct field_def *field, struct nlattr *nla)
+{
+	static char description[] = "\"\"";
+
+	return description;
+}
+
+static bool put_key_serial(struct context_def *ctx, const struct field_def *field,
+                       struct msg_buff *msg, const char *value)
+{
+	nla_put_u32(msg, field->nla_type, 0);
+	return true;
+}
+
+static int key_serial_usage(const struct field_def *field, char *str, int size)
+{
+	return snprintf(str, size,"[--%s=<n/a>]",
+	                field->name);
+}
+
+static void key_serial_describe_xml(const struct field_def *field)
+{
+	printf("\t<option name=\"%s\" type=\"string\">\n"
+	       "\t</option>\n",
+	       field->name);
+}
+
+static enum check_codes key_serial_check(const struct field_def *field, const char *value)
+{
+	return CC_OK;
+}
+
+#endif
+
 struct field_class fc_key_serial = {
 	.is_default = key_serial_is_default,
 	.is_equal = key_serial_is_equal,
@@ -844,6 +894,7 @@ struct field_class fc_key_serial = {
 	.ops = &fc_key_serial,					\
 	.u = { .k = {						\
 		.type = key_type, } }				\
+
 /* ============================================================================================== */
 
 const char *wire_protocol_map[] = {
@@ -1226,6 +1277,8 @@ struct context_def create_md_ctx = {
 		{ .name = "al-stripes", .argument_is_optional = false },
 		{ .name = "al-stripe-size-kB", .argument_is_optional = false },
 		{ .name = "force", .argument_is_optional = true },
+		{ .name = "effective-size", .argument_is_optional = false },
+		{ .name = "diskful-peers", .argument_is_optional = false },
 		{ } },
 };
 
@@ -1308,4 +1361,5 @@ struct context_def startup_options_ctx = {
 };
 
 struct context_def wildcard_ctx = {
+       .fields = { { } },
 };
