@@ -6,6 +6,7 @@
    Copyright (C) 2002-2008, LINBIT Information Technologies GmbH.
    Copyright (C) 2002-2008, Philipp Reisner <philipp.reisner@linbit.com>.
    Copyright (C) 2002-2008, Lars Ellenberg <lars.ellenberg@linbit.com>.
+   Copyright (C) 2008-2024, LINBIT HA-Solutions GmbH.
 
    drbd is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -58,6 +59,7 @@
 #include "config_flags.h"
 #include "drbdadm_dump.h"
 #include "shared_main.h"
+#include "shared_parser.h"
 #include "drbdadm_parser.h"
 
 #define MAX_ARGS 40
@@ -169,7 +171,6 @@ int do_register = 1;
 int adjust_more_than_one_resource = 0;
 char *drbdsetup = NULL;
 char *drbdmeta = NULL;
-char *drbdadm_83 = NULL;
 char *drbdadm_84 = NULL;
 char *drbd_proxy_ctl;
 char *sh_varname = NULL;
@@ -1175,7 +1176,7 @@ static bool is_valid_backend_option(const char* name, const struct context_def *
 	return false;
 }
 
-static void add_setup_options(char **argv, int *argcp, const struct context_def *context_def)
+static void add_setup_options(const char **argv, int *argcp, const struct context_def *context_def)
 {
 	struct d_name *b_opt;
 	int argc = *argcp;
@@ -1223,7 +1224,7 @@ ssprintf(strcmp((A)->af, "ipv6") ? "%s:%s:%s" : "%s:[%s]:%s",	\
 static int adm_attach(const struct cfg_ctx *ctx)
 {
 	struct d_volume *vol = ctx->vol;
-	char *argv[MAX_ARGS];
+	const char *argv[MAX_ARGS];
 	int argc = 0;
 	bool do_attach = (ctx->cmd == &attach_cmd);
 	bool reset = (ctx->cmd == &disk_options_defaults_cmd);
@@ -1246,11 +1247,13 @@ static int adm_attach(const struct cfg_ctx *ctx)
 	}
 
 	argv[NA(argc)] = drbdsetup;
-	argv[NA(argc)] = (char *)ctx->cmd->name; /* "attach" : "disk-options"; */
+	argv[NA(argc)] = ctx->cmd->name; /* "attach" : "disk-options"; */
 	argv[NA(argc)] = ssprintf("%d", vol->device_minor);
 	if (do_attach) {
 		assert(vol->disk != NULL);
+		assert(vol->meta_disk != NULL);
 		assert(vol->disk[0] != '\0');
+		assert(vol->meta_disk[0] != '\0');
 		argv[NA(argc)] = vol->disk;
 		if (!strcmp(vol->meta_disk, "internal")) {
 			argv[NA(argc)] = vol->disk;
@@ -1299,16 +1302,16 @@ bool del_opt(struct options *base, const char * const name)
 
 int adm_new_minor(const struct cfg_ctx *ctx)
 {
-	char *argv[MAX_ARGS];
+	const char *argv[MAX_ARGS];
 	int argc = 0, ex;
 
 	argv[NA(argc)] = drbdsetup;
 	argv[NA(argc)] = "new-minor";
-	argv[NA(argc)] = ssprintf("%s", ctx->res->name);
+	argv[NA(argc)] = ctx->res->name;
 	argv[NA(argc)] = ssprintf("%u", ctx->vol->device_minor);
 	argv[NA(argc)] = ssprintf("%u", ctx->vol->vnr);
 	if (!ctx->vol->disk)
-		argv[NA(argc)] = ssprintf("--diskless");
+		argv[NA(argc)] = "--diskless";
 	make_options(argv[NA(argc)], &ctx->vol->device_options, ctx->cmd->drbdsetup_ctx);
 	argv[NA(argc)] = NULL;
 
@@ -1325,14 +1328,14 @@ int adm_new_minor(const struct cfg_ctx *ctx)
 static int adm_resource(const struct cfg_ctx *ctx)
 {
 	struct d_resource *res = ctx->res;
-	char *argv[MAX_ARGS];
+	const char *argv[MAX_ARGS];
 	int argc = 0, ex;
 	bool do_new_resource = (ctx->cmd == &new_resource_cmd);
 	bool reset = (ctx->cmd == &res_options_defaults_cmd);
 
 	argv[NA(argc)] = drbdsetup;
-	argv[NA(argc)] = (char *)ctx->cmd->name; /* "new-resource" or "resource-options" */
-	argv[NA(argc)] = ssprintf("%s", res->name);
+	argv[NA(argc)] = ctx->cmd->name; /* "new-resource" or "resource-options" */
+	argv[NA(argc)] = res->name;
 	if (do_new_resource)
 		argv[NA(argc)] = ctx->res->me->node_id;
 	if (reset)
@@ -1370,7 +1373,7 @@ static off_t read_drbd_dev_size(int minor)
 
 int adm_resize(const struct cfg_ctx *ctx)
 {
-	char *argv[MAX_ARGS];
+	const char *argv[MAX_ARGS];
 	struct d_option *opt;
 	bool is_resize = !strcmp(ctx->cmd->name, "resize");
 	off_t old_size = -1;
@@ -1472,13 +1475,18 @@ bool is_set_gi_single_node(const struct cfg_ctx *ctx)
 
 int _adm_drbdmeta(const struct cfg_ctx *ctx, int flags, char *argument)
 {
+	/* that's enough for "--diskful-peers=" + a comma separated list of 0 .. 31 and then some */
+	char diskful_peers[120] = "";
+
 	struct d_volume *vol = ctx->vol;
-	char *argv[MAX_ARGS];
+	const char *argv[MAX_ARGS];
 	int argc = 0;
 
 	argv[NA(argc)] = drbdmeta;
 	argv[NA(argc)] = ssprintf("%d", vol->device_minor);
 	argv[NA(argc)] = "v09";
+	assert(vol->meta_disk != NULL);
+	assert(vol->meta_disk[0] != '\0');
 	if (!strcmp(vol->meta_disk, "internal")) {
 		assert(vol->disk != NULL);
 		assert(vol->disk[0] != '\0');
@@ -1501,10 +1509,47 @@ int _adm_drbdmeta(const struct cfg_ctx *ctx, int flags, char *argument)
 		else
 			argv[NA(argc)] = ssprintf("--node-id=%s", ctx->conn->peer->node_id);
 	}
-	argv[NA(argc)] = (char *)ctx->cmd->name;
+	argv[NA(argc)] = ctx->cmd->name;
 	if (argument)
 		argv[NA(argc)] = argument;
 	add_setup_options(argv, &argc, ctx->cmd->drbdsetup_ctx);
+
+	/* For create-md, if effective-size is set,
+	 * add the list of "diskful" peer node ids for this volume.
+	 * Unless that is explicitly specified as well.  */
+	if (!strcmp("create-md", ctx->cmd->name)
+	&& find_backend_option("--effective-size")
+	&& !find_backend_option("--diskful-peers")) {
+		struct connection *conn;
+		char sep = '=';
+		char *pos = diskful_peers;
+		int len;
+		len = snprintf(pos, pos - diskful_peers + sizeof(diskful_peers), "--diskful-peers");
+		assert(len > 0 && pos + len < diskful_peers + sizeof(diskful_peers));
+		pos += len;
+		for_each_connection(conn, &ctx->res->connections) {
+			struct peer_device *peer_device;
+
+			if (conn->ignore)
+				continue;
+
+			STAILQ_FOREACH(peer_device, &conn->peer_devices, connection_link) {
+				if (peer_device->vnr == vol->vnr) {
+					if (!peer_diskless(peer_device)) {
+						len = snprintf(pos, pos - diskful_peers + sizeof(diskful_peers),
+								"%c%s", sep, conn->peer->node_id);
+						assert(len > 0 && pos + len < diskful_peers + sizeof(diskful_peers));
+						pos += len;
+						sep = ',';
+					}
+					break;
+				}
+			}
+		}
+		if (sep != '=')
+			argv[NA(argc)] = diskful_peers;
+	}
+
 	argv[NA(argc)] = 0;
 
 	return m_system_ex(argv, flags, ctx->res->name);
@@ -1517,21 +1562,21 @@ static int adm_drbdmeta(const struct cfg_ctx *ctx)
 
 static void __adm_drbdsetup(const struct cfg_ctx *ctx, int flags, pid_t *pid, int *fd, int *ex)
 {
-	char *argv[MAX_ARGS];
+	const char *argv[MAX_ARGS];
 	int argc = 0;
 
 	argv[NA(argc)] = drbdsetup;
-	argv[NA(argc)] = (char *)ctx->cmd->name;
+	argv[NA(argc)] = ctx->cmd->name;
 
 	if (ctx->cmd->backend_res_name && ctx->res)
-		argv[NA(argc)] = ssprintf("%s", ctx->res->name);
+		argv[NA(argc)] = ctx->res->name;
 
 	if (ctx->cmd->need_peer)
-		argv[NA(argc)] = ssprintf("%s", ctx->conn->peer->node_id);
+		argv[NA(argc)] = ctx->conn->peer->node_id;
 
 	if (ctx->vol) {
 		if (ctx->cmd == &detach_cmd && !ctx->vol->device)
-			argv[NA(argc)] = ssprintf("--diskless");
+			argv[NA(argc)] = "--diskless";
 
 		if (ctx->cmd->need_peer && ctx->cmd->iterate_volumes)
 			argv[NA(argc)] = ssprintf("%d", ctx->vol->vnr);
@@ -1544,7 +1589,7 @@ static void __adm_drbdsetup(const struct cfg_ctx *ctx, int flags, pid_t *pid, in
 		int i;
 
 		for (i = 0; i < verbose; i++)
-			argv[NA(argc)] = ssprintf("--verbose");
+			argv[NA(argc)] = "--verbose";
 	}
 
 	add_setup_options(argv, &argc, ctx->cmd->drbdsetup_ctx);
@@ -1663,6 +1708,11 @@ static int adm_outdate(const struct cfg_ctx *ctx)
 	return rv;
 }
 
+bool backing_device_configured(const struct cfg_ctx *ctx)
+{
+	return (ctx->vol && ctx->vol->disk && ctx->vol->meta_disk);
+}
+
 /* shell equivalent:
  * ( drbdsetup resize && drbdsetup check-resize ) || drbdmeta check-resize */
 static int adm_chk_resize(const struct cfg_ctx *ctx)
@@ -1670,17 +1720,18 @@ static int adm_chk_resize(const struct cfg_ctx *ctx)
 	/* drbdsetup resize && drbdsetup check-resize */
 	int ex = adm_resize(ctx);
 	if (ex == 0)
-		return 0;
+		return ex;
+
+	if (!backing_device_configured(ctx)) {
+		fprintf(stderr, "No backing device configured for drbd%u, cannot fall back to drbdmeta.\n",
+			ctx->vol->device_minor);
+		return ex;
+	}
 
 	/* try drbdmeta check-resize */
 	return adm_drbdmeta(ctx);
 }
 
-bool backing_device_configured(const struct cfg_ctx *ctx)
-{
-	return (ctx->vol && ctx->vol->disk && ctx->vol->meta_disk);
-}
-
 /* try drbdsetup first (i.e., what does the kernel know
  * if it fails, try drbdmeta */
 static int adm_setup_and_meta(const struct cfg_ctx *ctx)
@@ -1787,7 +1838,7 @@ static int adm_khelper(const struct cfg_ctx *ctx)
 	char *sh_cmd;
 	char minor_string[8];
 	char volume_string[8];
-	char *argv[4] = { NULL, };
+	const char *argv[4] = { NULL, };
 
 	setenv("DRBD_CONF", config_save, 1);
 	setenv("DRBD_RESOURCE", res->name, 1);
@@ -1872,7 +1923,7 @@ int adm_peer_device(const struct cfg_ctx *ctx)
 	struct connection *conn = ctx->conn;
 	struct d_volume *vol = ctx->vol;
 	struct peer_device *peer_device;
-	char *argv[MAX_ARGS];
+	const char *argv[MAX_ARGS];
 	int argc = 0;
 
 	peer_device = find_peer_device(conn, vol->vnr);
@@ -1882,10 +1933,10 @@ int adm_peer_device(const struct cfg_ctx *ctx)
 	}
 
 	argv[NA(argc)] = drbdsetup;
-	argv[NA(argc)] = (char *)ctx->cmd->name; /* peer-device-options */
+	argv[NA(argc)] = ctx->cmd->name; /* peer-device-options */
 
-	argv[NA(argc)] = ssprintf("%s", res->name);
-	argv[NA(argc)] = ssprintf("%s", conn->peer->node_id);
+	argv[NA(argc)] = res->name;
+	argv[NA(argc)] = conn->peer->node_id;
 	argv[NA(argc)] = ssprintf("%d", vol->vnr);
 
 	if (reset)
@@ -1902,13 +1953,13 @@ static int adm_connect(const struct cfg_ctx *ctx)
 {
 	struct d_resource *res = ctx->res;
 	struct connection *conn = ctx->conn;
-	char *argv[MAX_ARGS];
+	const char *argv[MAX_ARGS];
 	int argc = 0;
 
 	argv[NA(argc)] = drbdsetup;
-	argv[NA(argc)] = (char *)ctx->cmd->name; /* "connect" */
-	argv[NA(argc)] = ssprintf("%s", res->name);
-	argv[NA(argc)] = ssprintf("%s", conn->peer->node_id);
+	argv[NA(argc)] = ctx->cmd->name; /* "connect" */
+	argv[NA(argc)] = res->name;
+	argv[NA(argc)] = conn->peer->node_id;
 
 	add_setup_options(argv, &argc, ctx->cmd->drbdsetup_ctx);
 	argv[NA(argc)] = 0;
@@ -1921,15 +1972,15 @@ static int adm_new_peer(const struct cfg_ctx *ctx)
 	struct d_resource *res = ctx->res;
 	struct connection *conn = ctx->conn;
 
-	char *argv[MAX_ARGS];
+	const char *argv[MAX_ARGS];
 	int argc = 0;
 
 	bool reset = (ctx->cmd == &net_options_defaults_cmd);
 
 	argv[NA(argc)] = drbdsetup;
-	argv[NA(argc)] = (char *)ctx->cmd->name; /* "new-peer", "net-options" */
-	argv[NA(argc)] = ssprintf("%s", res->name);
-	argv[NA(argc)] = ssprintf("%s", conn->peer->node_id);
+	argv[NA(argc)] = ctx->cmd->name; /* "new-peer", "net-options" */
+	argv[NA(argc)] = res->name;
+	argv[NA(argc)] = conn->peer->node_id;
 
 	if (reset)
 		argv[NA(argc)] = "--set-defaults";
@@ -1950,14 +2001,13 @@ static int adm_path(const struct cfg_ctx *ctx)
 	struct d_resource *res = ctx->res;
 	struct connection *conn = ctx->conn;
 	struct path *path = ctx->path;
-
-	char *argv[MAX_ARGS];
+	const char *argv[MAX_ARGS];
 	int argc = 0;
 
 	argv[NA(argc)] = drbdsetup;
-	argv[NA(argc)] = (char *)ctx->cmd->name; /* add-path, del-path */
-	argv[NA(argc)] = ssprintf("%s", res->name);
-	argv[NA(argc)] = ssprintf("%s", conn->peer->node_id);
+	argv[NA(argc)] = ctx->cmd->name; /* add-path, del-path */
+	argv[NA(argc)] = res->name;
+	argv[NA(argc)] = conn->peer->node_id;
 
 	argv[NA(argc)] = ssprintf_addr(path->my_address);
 	argv[NA(argc)] = ssprintf_addr(path->connect_to);
@@ -1995,7 +2045,7 @@ char *_proxy_connection_name(char *conn_name, const struct d_resource *res, cons
 
 static int do_proxy_conn_up(const struct cfg_ctx *ctx)
 {
-	char *argv[4] = { drbd_proxy_ctl, "-c", NULL, NULL };
+	const char *argv[4] = { drbd_proxy_ctl, "-c", NULL, NULL };
 	struct connection *conn = ctx->conn;
 	struct path *path = STAILQ_FIRST(&conn->paths); /* multiple paths via proxy, later! */
 	char *conn_name;
@@ -2024,7 +2074,7 @@ static int do_proxy_conn_plugins(const struct cfg_ctx *ctx)
 {
 	struct connection *conn = ctx->conn;
 	struct path *path = STAILQ_FIRST(&conn->paths); /* multiple paths via proxy, later! */
-	char *argv[MAX_ARGS];
+	const char *argv[MAX_ARGS];
 	char *conn_name;
 	int argc = 0;
 	struct d_option *opt;
@@ -2066,7 +2116,7 @@ static int do_proxy_conn_down(const struct cfg_ctx *ctx)
 	struct connection *conn = ctx->conn;
 	struct path *path = STAILQ_FIRST(&conn->paths); /* multiple paths via proxy, later! */
 	char *conn_name;
-	char *argv[4] = { drbd_proxy_ctl, "-c", NULL, NULL};
+	const char *argv[4] = { drbd_proxy_ctl, "-c", NULL, NULL};
 
 	if (!path->my_proxy || !path->peer_proxy)
 		return 0;
@@ -2199,19 +2249,19 @@ static int adm_wait_c(const struct cfg_ctx *ctx)
 {
 	struct d_resource *res = ctx->res;
 	struct d_volume *vol = ctx->vol;
-	char *argv[MAX_ARGS];
+	const char *argv[MAX_ARGS];
 	int argc = 0, rv;
 
 	argv[NA(argc)] = drbdsetup;
 	if (ctx->vol && ctx->conn) {
 		argv[NA(argc)] = ssprintf("%s-%s", ctx->cmd->name, "volume");
 		argv[NA(argc)] = res->name;
-		argv[NA(argc)] = ssprintf("%s", ctx->conn->peer->node_id);
+		argv[NA(argc)] = ctx->conn->peer->node_id;
 		argv[NA(argc)] = ssprintf("%d", vol->vnr);
 	} else if (ctx->conn) {
 		argv[NA(argc)] = ssprintf("%s-%s", ctx->cmd->name, "connection");
 		argv[NA(argc)] = res->name;
-		argv[NA(argc)] = ssprintf("%s", ctx->conn->peer->node_id);
+		argv[NA(argc)] = ctx->conn->peer->node_id;
 	} else {
 		argv[NA(argc)] = ssprintf("%s-%s", ctx->cmd->name, "resource");
 		argv[NA(argc)] = res->name;
@@ -2572,7 +2622,8 @@ static int check_exit_codes(pid_t * pids)
 static int adm_wait_ci(const struct cfg_ctx *ctx)
 {
 	struct d_resource *res;
-	char *argv[20], answer[40];
+	const char *argv[20];
+	char answer[40];
 	pid_t *pids;
 	int rr, wtime, argc, i = 0;
 	time_t start;
@@ -3490,24 +3541,15 @@ int main(int argc, char **argv)
 		config_save = canonify_path(config_file);
 
 	my_parse();
+	fclose(yyin);
 
 	if (config_test) {
-		char *saved_config_file = config_file;
-		char *saved_config_save = config_save;
-
-		config_file = config_test;
-		config_save = canonify_path(config_test);
-
-		fclose(yyin);
-		yyin = fopen(config_test, "r");
-		if (!yyin) {
+		FILE *f = fopen(config_test, "r");
+		if (!f) {
 			log_err("Can not open '%s'.\n.", config_test);
 			exit(E_EXEC_ERROR);
 		}
-		my_parse();
-
-		config_file = saved_config_file;
-		config_save = saved_config_save;
+		include_file(f, config_test);
 	}
 
 	if (!config_valid)
