@@ -66,19 +66,6 @@ void maybe_exec_legacy_drbdadm(char **argv)
 {
 	const struct version *driver_version = drbd_driver_version(FALLBACK_TO_UTILS);
 
-	if (driver_version->version.major == 8 &&
-	    driver_version->version.minor == 3) {
-#ifdef DRBD_LEGACY_83
-		/* This drbdadm warned already... */
-		setenv("DRBD_DONT_WARN_ON_VERSION_MISMATCH", "1", 0);
-		add_lib_drbd_to_path();
-		execvp(drbdadm_83, argv);
-		log_err("execvp() failed to exec %s: %m\n", drbdadm_83);
-#else
-		config_help_legacy("drbdadm", driver_version);
-#endif
-		exit(E_EXEC_ERROR);
-	}
 	if (driver_version->version.major == 8 &&
 	    driver_version->version.minor == 4) {
 #ifdef DRBD_LEGACY_84
