@@ -19,6 +19,8 @@ extern const char *quorum_color_start(bool);
 extern const char *quorum_color_stop(bool);
 extern const char *fail_io_color_start(bool);
 extern const char *fail_io_color_stop(bool);
+extern const char *dev_is_open_color_start(bool);
+extern const char *dev_is_open_color_stop(bool);
 
 #define REPL_COLOR_STRING(__r)  \
 	repl_state_color_start(__r), drbd_repl_str(__r), repl_state_color_stop(__r)
