@@ -6,6 +6,7 @@
  * Copyright (C) 2001-2008, LINBIT Information Technologies GmbH.
  * Copyright (C) 1999-2008, Philipp Reisner <philipp.reisner@linbit.com>.
  * Copyright (C) 2002-2008, Lars Ellenberg <lars.ellenberg@linbit.com>.
+ * Copyright (C) 2008-2024, LINBIT HA-Solutions GmbH.
  *
  * drbd is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -541,6 +542,11 @@ static struct promotion_info compute_promotion_info(struct resources_list *resou
 	if (!resource->devices)
 		return info;
 
+	/* Do not attempt to promote a resource that is failing IO.  That may
+	 * be a "--force secondary" still held open by old references. */
+	if (resource->info.res_fail_io)
+		return info;
+
 	for (device = resource->devices; device; device = device->next) {
 		int up_to_date_replicas = count_up_to_date_replicas(resource, device);
 		bool stable_up_to_date_replicas = have_stable_up_to_date_replicas(resource, device);
@@ -681,7 +687,8 @@ static void print_device_changes(const char *prefix, const char *action_new, con
 	bool statistics_changed;
 
 	info_changed = !old_device || new_device->info.dev_disk_state != old_device->info.dev_disk_state ||
-		new_device->info.dev_has_quorum != old_device->info.dev_has_quorum;
+		new_device->info.dev_has_quorum != old_device->info.dev_has_quorum ||
+		new_device->info.dev_is_open != old_device->info.dev_is_open;
 	statistics_changed = opt_statistics &&
 		(!old_device ||
 		 memcmp(&new_device->statistics, &old_device->statistics, sizeof(struct device_statistics)));
@@ -722,6 +729,15 @@ static void print_device_changes(const char *prefix, const char *action_new, con
 			else
 				printf(" client:%s", intentional_diskless_str(&new_device->info));
 
+			if (!old_device || old_device->info.dev_is_open != new_device->info.dev_is_open) {
+				const char *old_dev_is_open = UNKNOWN_STRING;
+				if (old_device)
+					old_dev_is_open = no_yes_unknown_str(old_device->info.dev_is_open);
+				printf(" open:%s->%s",
+					old_dev_is_open, no_yes_unknown_str(new_device->info.dev_is_open));
+			} else
+				printf(" open:%s", no_yes_unknown_str(new_device->info.dev_is_open));
+
 			if (!old_device || old_device->info.dev_has_quorum != new_device->info.dev_has_quorum) {
 				char *old_dev_has_quorum = UNKNOWN_STRING;
 				if (old_device)
@@ -737,6 +753,7 @@ static void print_device_changes(const char *prefix, const char *action_new, con
 			printf(" disk:%s%s%s",
 					DISK_COLOR_STRING(new_device->info.dev_disk_state, intentional, true));
 			printf(" client:%s", intentional_diskless_str(&new_device->info));
+			printf(" open:%s", no_yes_unknown_str(new_device->info.dev_is_open));
 			printf(" quorum:%s", new_device->info.dev_has_quorum ? "yes" : "no");
 		}
 	}
@@ -1061,17 +1078,50 @@ static struct nlmsg_entry *nlmsg_copy(struct genl_info *info)
 	return entry;
 }
 
+static int apply_stored_event(const char *timestamp_prefix, struct nlmsg_entry *entry)
+{
+	struct nlattr *tla[ARRAY_SIZE(drbd_tla_nl_policy)];
+	struct genl_info stored_info = {
+		.seq = entry->nlh->nlmsg_seq,
+		.nlhdr = entry->nlh,
+		.genlhdr = nlmsg_data(entry->nlh),
+		.userhdr = genlmsg_data(nlmsg_data(entry->nlh)),
+		.attrs = tla,
+	};
+	int err;
+
+	err = drbd_tla_parse(stored_info.attrs, entry->nlh);
+	if (err) {
+		fprintf(stderr, "drbd_tla_parse() failed");
+		return 1;
+	}
+
+	err = apply_event(timestamp_prefix, &stored_info);
+
+	free(entry->nlh);
+	free(entry);
+
+	return err;
+}
+
+static bool seq_a_less_or_equal_b(uint32_t a, uint32_t b)
+{
+	return (int32_t)a - (int32_t)b <= 0;
+}
+
 int print_event(struct drbd_cmd *cm, struct genl_info *info, void *u_ptr)
 {
-	static uint32_t last_seq;
-	static bool last_seq_known;
+	static uint32_t next_seq; /* nlmsg_seq of the next message to apply */
+	static bool next_seq_known;
 	static struct nlmsg_entry *stored_messages = NULL;
+	static struct nlmsg_entry **tail_next = &stored_messages;
 
 	struct drbd_notification_header nh = { .nh_type = -1U };
 	enum drbd_notification_type action;
 	struct drbd_genlmsghdr *dh;
 	int err;
 	char timestamp_prefix[TIMESTAMP_LEN];
+	struct nlmsg_entry *entry, **iter_prev_next;
 
 	if (!info)
 		return 0;
@@ -1092,68 +1142,59 @@ int print_event(struct drbd_cmd *cm, struct genl_info *info, void *u_ptr)
 		exit(20);
 
 	if (info->genlhdr->cmd == DRBD_INITIAL_STATE_DONE) {
-		struct nlmsg_entry *entry, *next_entry;
-
 		if (initial_state)
 			printf("%s%s -\n", timestamp_prefix, action_exists);
 		fflush(stdout);
 
 		initial_state = false;
 		receive_update = false;
+	} else if (action == NOTIFY_EXISTS) {
+		/* apply initial state "exists" messages immediately */
+		return apply_event(timestamp_prefix, info);
+	} else {
+		uint32_t seq = info->nlhdr->nlmsg_seq;
+		struct nlmsg_entry *entry = nlmsg_copy(info);
 
-		/* now apply stored messages */
-		for (entry = stored_messages; entry; entry = next_entry) {
-			struct nlattr *tla[ARRAY_SIZE(drbd_tla_nl_policy)];
-			struct genl_info stored_info = {
-				.seq = entry->nlh->nlmsg_seq,
-				.nlhdr = entry->nlh,
-				.genlhdr = nlmsg_data(entry->nlh),
-				.userhdr = genlmsg_data(nlmsg_data(entry->nlh)),
-				.attrs = tla,
-			};
+		if (!next_seq_known) {
+			next_seq = seq;
+			next_seq_known = true;
+		}
 
-			err = drbd_tla_parse(stored_info.attrs, entry->nlh);
-			if (err) {
-				fprintf(stderr, "drbd_tla_parse() failed");
-				return 1;
-			}
+		*tail_next = entry;
+		tail_next = &entry->next;
+	}
 
-			err = apply_event(timestamp_prefix, &stored_info);
+	if (initial_state || receive_update)
+		return 0;
+
+	/* apply messages in order according to their nlmsg_seq values */
+restart:
+	iter_prev_next = &stored_messages;
+	entry = stored_messages;
+	while (entry) {
+		/* if the first messages were out-of-order, seq may decrease */
+		if (seq_a_less_or_equal_b(entry->nlh->nlmsg_seq, next_seq)) {
+			if (tail_next == &entry->next) /* tail element will be freed */
+				tail_next = iter_prev_next;
+
+			if (entry->nlh->nlmsg_seq == next_seq)
+				next_seq++;
+
+			/* remove entry from list */
+			*iter_prev_next = entry->next;
+
+			err = apply_stored_event(timestamp_prefix, entry);
 			if (err)
 				return err;
 
-			next_entry = entry->next;
-			free(entry->nlh);
-			free(entry);
-		}
-		stored_messages = NULL;
-
-		return 0;
-	}
-
-	if (action != NOTIFY_EXISTS) {
-		if (last_seq_known) {
-			int skipped = info->nlhdr->nlmsg_seq - (last_seq + 1);
-
-			if (skipped) {
-				printf("%s- skipped %d\n", timestamp_prefix, skipped);
-				fflush(stdout);
-			}
-		}
-		last_seq = info->nlhdr->nlmsg_seq;
-		last_seq_known = true;
-
-		if (initial_state || receive_update) {
-			/* store message until initial state is finished */
-			struct nlmsg_entry *entry, **previous_next = &stored_messages;
-			for (entry = stored_messages; entry; entry = entry->next)
-				previous_next = &entry->next;
-			*previous_next = nlmsg_copy(info);
-			return 0;
+			goto restart;
+		} else {
+			iter_prev_next = &entry->next;
+			entry = entry->next;
 		}
 	}
 
-	return apply_event(timestamp_prefix, info);
+	return 0;
 }
 
 static int apply_event(const char *prefix, struct genl_info *info)
@@ -1252,6 +1293,7 @@ static int apply_event(const char *prefix, struct genl_info *info)
 			disk_conf_from_attrs(&device->disk_conf, info);
 			device->info.dev_disk_state = D_DISKLESS;
 			device->info.is_intentional_diskless = IS_INTENTIONAL_DEF;
+			device->info.dev_is_open = DEV_IS_OPEN_UNKNOWN;
 			device_info_from_attrs(&device->info, info);
 			memset(&device->statistics, -1, sizeof(device->statistics));
 			device_statistics_from_attrs(&device->statistics, info);
