@@ -113,6 +113,7 @@ void test_device_info(struct msg_buff *smsg, __u32 dev_disk_state, __u8 dev_has_
 	struct nlattr *nla = nla_nest_start(smsg, DRBD_NLA_DEVICE_INFO);
 	nla_put_u32(smsg, T_dev_disk_state, dev_disk_state);
 	nla_put_u8(smsg, T_is_intentional_diskless, false);
+	nla_put_u8(smsg, T_dev_is_open, false);
 	nla_put_u8(smsg, T_dev_has_quorum, dev_has_quorum);
 	nla_put_string(smsg, T_backing_dev_path, backing_dev(dev_disk_state));
 	nla_nest_end(smsg, nla);
@@ -542,15 +543,21 @@ int test_events2()
 	char input[MAX_INPUT_LENGTH];
 
 	while (fgets(input, MAX_INPUT_LENGTH, stdin)) {
+		char msg_name[MAX_INPUT_LENGTH];
+		int index;
+		int argument_count;
 		struct msg_buff *smsg;
 		struct nlmsghdr *nlh;
 		int err;
 
-		input[strcspn(input, "\n")] = 0;
+		argument_count = sscanf(input, "%s %d", msg_name, &index);
+
+		if (argument_count >= 2)
+			msg_index = index;
 
 		/* build msg as if sending */
 		smsg = msg_new(DEFAULT_MSG_SIZE);
-		err = test_build_msg(smsg, input);
+		err = test_build_msg(smsg, msg_name);
 		if (err) {
 			msg_free(smsg);
 			return err;
@@ -604,6 +611,8 @@ int main(int argc, char **argv)
 		case 'h':
 		case '?':
 			fprintf(stderr, "drbdsetup_events2_instrumented - Fake drbdsetup events2 from messages on stdin\n\n");
+			fprintf(stderr, "Input line format:\n");
+			fprintf(stderr, "message_name [sequence_number]\n\n");
 			fprintf(stderr, "USAGE: %s [options]\n", argv[0]);
 			fprintf(stderr, "    [--timestamps] [--statistics] [--now] [--diff] [--full] [--color]\n");
 			return 1;
